<script>import { randomID } from '../../styles';
import { createEventForwarder, useActions } from '../../internal';
import { get_current_component } from 'svelte/internal';
import Input from '../Input/Input.svelte';
import InputWrapper from '../InputWrapper/InputWrapper.svelte';
import ChevronUpDown from './ChevronUpDown.svelte';
export let use = [], element = undefined, className = '', override = {}, id = 'NativeSelect', placeholder = '', data = [], inputStyle = {}, wrapperProps = {}, size = 'sm', icon = null, iconWidth = 36, iconProps = { size: 20, color: 'currentColor' }, rightSectionWidth = 36, rightSectionProps = {}, required = false, radius = 'sm', variant = 'default', disabled = false, value = '', label = '', description = '', error = '', labelProps = {}, descriptionProps = {}, errorProps = {};
export { className as class };
/** Generate random id for label and select elements*/
const uuid = randomID(id);
/** Map through the data and format it*/
let formattedData = [];
$: data &&
    (formattedData = data.map((item) => typeof item === 'string' ? { label: item, value: item } : item));
/** An action that forwards inner dom node events from parent component */
const forwardEvents = createEventForwarder(get_current_component());
/** When no icon is present give the left section 12px of padding*/
const base = { '& .input': { paddingLeft: 12 } };
</script>

<!--
@component

Capture user feedback limited to large set of options

@see https://svelteui.dev/core/native-select
@example
    ```svelte
    <NativeSelect
      data={['React', 'Vue', 'Angular', 'Svelte']}
      placeholder="Pick one"
      label="Select your favorite framework/library"
      description="This is anonymous"
      required
    />
    ```
-->
<InputWrapper
	id={uuid}
	class="{className} svelteui-NativeSelect-root"
	{size}
	{label}
	{error}
	{override}
	{required}
	{labelProps}
	{errorProps}
	{description}
	{descriptionProps}
	{...wrapperProps}
>
	<Input
		bind:element
		use={[forwardEvents, [useActions, use]]}
		bind:value
		root="select"
		id={uuid}
		autocomplete="off"
		invalid={Boolean(error)}
		override={{ ...base, ...inputStyle }}
		noPointerEventsRightSection
		{size}
		{icon}
		{radius}
		{variant}
		{required}
		{disabled}
		{iconWidth}
		{iconProps}
		{placeholder}
		{rightSectionWidth}
		{rightSectionProps}
		{...$$restProps}
	>
		{#if placeholder}
			<option value="" disabled hidden selected={!value}>
				{placeholder}
			</option>
		{/if}
		<slot slot="icon" name="icon" />
		{#each formattedData as item}
			<option value={item.value} disabled={item.disabled} selected={item.value === value}>
				{item.label ?? item.value}
			</option>
		{:else}
			<option value="" disabled hidden>Add Some Options</option>
		{/each}
		<svelte:fragment slot="rightSection">
			<slot name="rightSection" size={iconProps.size} color={iconProps.color}>
				<svelte:component this={ChevronUpDown} size={iconProps.size} color={iconProps.color} />
			</slot>
		</svelte:fragment>
	</Input>
</InputWrapper>
